==> testdisk_6.14.orig.tar.bz2: testdisk-6.14/src/file_edb.c <==
/*

    File: file_edb.c

    Copyright (C) 2009 Christophe GRENIER <grenier@cgsecurity.org>

    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include <stdio.h>
#include "types.h"
#include "common.h"
#include "filegen.h"

static void register_header_check_edb(file_stat_t *file_stat);

const file_hint_t file_hint_edb= {
  .extension="edb",
  .description="Exchange Database",
  .min_header_distance=0,
  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
  .recover=1,
  .enable_by_default=1,
  .register_header_check=&register_header_check_edb
};


static int header_check_edb(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
{
  /* A backup of the header is stored in the second block */
  if(file_recovery!=NULL && file_recovery->file_stat!=NULL &&
      file_recovery->file_stat->file_hint==&file_hint_edb &&
      file_recovery->file_size==4096)
    return 0;
  reset_file_recovery(file_recovery_new);
  file_recovery_new->extension=file_hint_edb.extension;
  return 1;
}

static void register_header_check_edb(file_stat_t *file_stat)
{
  static const unsigned char edb_magic[8]= {
    0xef, 0xcd, 0xab, 0x89, 0x20, 0x06, 0x00, 0x00
  };
  register_header_check(4, edb_magic, sizeof(edb_magic), &header_check_edb, file_stat);
}

==> testdisk_7.0.orig.tar.bz2: testdisk-7.0/src/file_edb.c <==
/*

    File: file_edb.c

    Copyright (C) 2009 Christophe GRENIER <grenier@cgsecurity.org>

    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include <stdio.h>
#include "types.h"
#include "common.h"
#include "filegen.h"

static void register_header_check_edb(file_stat_t *file_stat);

const file_hint_t file_hint_edb= {
  .extension="edb",
  .description="Exchange Database",
  .min_header_distance=0,
  .max_filesize=PHOTOREC_MAX_FILE_SIZE,
  .recover=1,
  .enable_by_default=1,
  .register_header_check=&register_header_check_edb
};


static int header_check_edb(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
{
  /* A backup of the header is stored in the second block */
  if(file_recovery->file_stat!=NULL &&
      file_recovery->file_stat->file_hint==&file_hint_edb &&
      file_recovery->file_size==4096)
    return 0;
  reset_file_recovery(file_recovery_new);
  file_recovery_new->extension=file_hint_edb.extension;
  return 1;
}

static void register_header_check_edb(file_stat_t *file_stat)
{
  static const unsigned char edb_magic[8]= {
    0xef, 0xcd, 0xab, 0x89, 0x20, 0x06, 0x00, 0x00
  };
  register_header_check(4, edb_magic, sizeof(edb_magic), &header_check_edb, file_stat);
}
